/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;


/**
 * Corresponds to &lt;Alert&gt; element in SyncML represent DTD
 *
 *
 * @see    AlertCode
 *
 * @version $Id: Alert.java,v 1.2 2006/08/07 21:05:28 nichele Exp $
 */
public final class Alert
extends ItemizedCommand
implements java.io.Serializable {

    // --------------------------------------------------------------- Constants
    public static String COMMAND_NAME = "Alert";

    // ------------------------------------------------------------ Private data
    private int data;

    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected Alert() {}

    /**
     * Creates a new Alert object with the given command identifier,
     * noResponse, authentication credential, alert code and array of item
     *
     * @param cmdID command identifier - NOT NULL
     * @param noResp is true if no response is required
     * @param cred the authentication credential
     * @param data the code of Alert
     * @param items the array of item - NOT NULL
     *
     */
    public Alert(final CmdID cmdID,
                 final boolean noResp,
                 final Cred cred,
                 final int data,
                 final Item[] items) {
        super(cmdID, items);

        this.noResp  = (noResp) ? new Boolean(noResp) : null;
        setCred(cred);

        this.data = data;
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the alert code
     *
     * @return the alert code
     */
    public int getData() {
        return data;
    }

    /**
     * Sets the alert code
     *
     * @param data the alert code
     */
    public void setData(int data) {
        this.data = data;
    }

    /**
     * Gets the command name property
     *
     * @return the command name property
     */
    public String getName() {
        return Alert.COMMAND_NAME;
    }
}
