/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core;

/**
 * Contains the information for HMAC autenthication
 *
 *
 *
 * @version $Id: HMACAuthentication.java,v 1.2 2006/08/07 21:05:28 nichele Exp $
 */

public class HMACAuthentication extends Authentication {

    // --------------------------------------------------------------- Constants
    private final String DEFAULT_ALGORITHM = "MD5";


    // ------------------------------------------------------------ Private data
    private String userMac;
    private String algorithm;
    private String calculatedMac;


    // ------------------------------------------------------------ Constructors

    /** For serialization purposes */
    protected HMACAuthentication() {}



    public HMACAuthentication(final String data) {
        super(Constants.AUTH_TYPE_HMAC, Constants.FORMAT_B64, data);
    }


    // ---------------------------------------------------------- Public Methods

    /**
     * Gets the userMac property
     *
     * @return the userMac property
     */
    public String getUserMac() {
        return this.userMac;
    }


    /**
     * Sets the userMac property
     * @param userMac the userMac property
     */
    public void setUserMac(String userMac) {
        this.userMac = userMac;
    }

    /**
     * Gets the calculatedMac property
     *
     * @return the calculatedMac property
     */
    public String getCalculatedMac() {
        return this.calculatedMac;
    };


    /**
     * Sets the calculatedMac property
     * @param calculatedMac the calculatedMac property
     */
    public void setCalculatedMac(String calculatedMac) {
        this.calculatedMac = calculatedMac;
    };

    /**
     * Gets the algorithm property
     *
     * @return the algorithm property
     */
    public String getAlgorithm() {
        return this.algorithm;
    };


    /**
     * Sets the data property
     *
     * @param data the data property
     *
     */
    public void setData(String data) {
        if (data == null) {
            throw new IllegalArgumentException("data cannot be null");
        }


        // example
        // hmacHeader: algorithm=MD5, username="Robert Jordan", mac=Dgpoz8Pbs4XC0ecp6kLw4Q==


        // parse hmac header for algorithm

        int indexAlgorithm = data.indexOf("algorithm");
        int indexEndAlgorithm = -1;

        if (indexAlgorithm == -1) {
            algorithm = DEFAULT_ALGORITHM;
        } else {
            indexEndAlgorithm = data.indexOf(",", indexAlgorithm);
            algorithm = data.substring(indexAlgorithm + 10, indexEndAlgorithm);
        }

        // parse hmac header for username

        int indexUsername = data.indexOf("username", indexEndAlgorithm + 1);

        if (indexUsername == -1) {
            throw new IllegalArgumentException("Username missing in hmac header");
        }

        int indexEndUsername = data.indexOf("\"", indexUsername + 10);

        if (indexEndUsername == -1) {
            throw new IllegalArgumentException("Unable to get username from hmac header [" + data +
                                               "]");
        }

        // checks if the previous char is '\'
        while (data.charAt(indexEndUsername - 1) == '\\') {
            indexEndUsername = data.indexOf("\"", indexEndUsername + 1);
        }

        if (indexEndUsername == -1) {
            throw new IllegalArgumentException("Unable to get username from hmac header [" + data +
                                               "]");
        }

        setUsername(data.substring(indexUsername + 10, indexEndUsername));

        // parse hmac header for mac

        int indexMac = data.indexOf("mac", indexEndUsername);

        if (indexMac == -1) {
            throw new IllegalArgumentException("Mac value missing in hmac header");
        } else {
            userMac = data.substring(indexMac + 4);
        }

    }

}
