/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

/**
 * This class represents the &lt;Item&gt; tag as defined by the SyncML
 * representation specifications
 *
 *
 *
 * @version $Id: Item.java,v 1.2 2006/08/07 21:05:28 nichele Exp $
 */
public class Item
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data
    private Target target;
    private Source source;
    private Meta meta;
    private ComplexData data;
    private Boolean moreData;

    // ------------------------------------------------------------ Constructors

    protected Item() {}

    /**
     * Creates a new Item object.
     *
     * @param target item target - NULL ALLOWED
     * @param source item source - NULL ALLOWED
     * @param meta item meta data - NULL ALLOWED
     * @param data item data - NULL ALLOWED
     *
     */
    public Item(final Target target,
                final Source source,
                final Meta   meta  ,
                final ComplexData data,
                final boolean moreData) {
        this.target = target;
        this.source = source;
        this.meta   = meta  ;
        this.data   = data  ;
        this.moreData  = (moreData) ? new Boolean(moreData) : null;
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the item target
     *
     * @return the item target
     */
    public Target getTarget() {
        return target;
    }

    /**
     * Sets the item target
     *
     * @param target the target
     *
     */
    public void setTarget(Target target) {
        this.target = target;
    }

    /**
     * Returns the item source
     *
     * @return the item source
     */
    public Source getSource() {
        return source;
    }

    /**
     * Sets the item source
     *
     * @param source the source
     *
     */
    public void setSource(Source source) {
        this.source = source;
    }

    /**
     * Returns the item meta element
     *
     * @return the item meta element
     */
    public Meta getMeta() {
        return meta;
    }

    /**
     * Sets the meta item
     *
     * @param meta the item meta element
     *
     */
    public void setMeta(Meta meta) {
        this.meta = meta;
    }

    /**
     * Returns the item data
     *
     * @return the item data
     *
     */
    public ComplexData getData() {
        return data;
    }

    /**
     * Sets the item data
     *
     * @param data the item data
     *
     */
    public void setData(ComplexData data) {
        this.data = data;
    }

    /**
     * Gets moreData property
     *
     * @return true if the data item is incomplete and has further chunks
     *         to come, false otherwise
     */
    public boolean isMoreData() {
        return (moreData != null);
    }

    /**
     * Gets the Boolean value of moreData
     *
     * @return true if the data item is incomplete and has further chunks
     *         to come, false otherwise
     */
    public Boolean getMoreData() {
        if (!moreData.booleanValue()) {
            return null;
        }
        return moreData;
    }

    /**
     * Sets the moreData property
     *
     * @param moreData the moreData property
     */
    public void setMoreData(Boolean moreData) {
        this.moreData = (moreData.booleanValue()) ? moreData : null;
    }
}
