/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;

/**
 * This class is related to the "last" and "next" values in an &lt;Anchor&gt; tag
 * in the metainfo spec
 *
 *
 * @see    SyncAnchor
 *
 * @version $Id: SessionID.java,v 1.2 2006/08/07 21:05:28 nichele Exp $
 */
public final class SessionID
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private String sessionID;

    // ------------------------------------------------------------ Constructors

    /**
     * For serialization purposes
     */
    protected SessionID() {}

    /**
     * Create a new SessionID object with the parameters
     *
     * @param sessionID the identifier of session - NOT NULL
     *
     */
    public SessionID(final String sessionID) {
        setSessionID(sessionID);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the session identifier
     *
     * @return sessionID the session identifier
     */
    public String getSessionID() {
        return sessionID;
    }

    /**
     * Sets the session identifier
     *
     * @param sessionID the session identifier
     */
    public void setSessionID(String sessionID) {
        if (sessionID == null || sessionID.length() == 0) {
            throw new IllegalArgumentException(
                                          "sessionID cannot be null or empty");
        }
        this.sessionID = sessionID;
    }
}
