/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core;


/**
 * This class represents the &lt;TargetRef&gt; element as defined by the SyncML
 * representation specifications
 *
 *
 *
 * @version $Id: TargetRef.java,v 1.2 2006/08/07 21:09:19 nichele Exp $
 */
public final class TargetRef
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private String value;
    private Target target;

    // ------------------------------------------------------------ Constructors

    /**
     * For serialization purposes
     */
    protected TargetRef() {}

    /**
     * Creates a new TargetRef object given the referenced value. A null value
     * is considered an empty string
     *
     * @param value the referenced value - NULL ALLOWED
     *
     * @throws IllegalArgumentException if value is null
     */
    public TargetRef(final String value) {
        setValue(value);
    }

    /**
     * Creates a new TargetRef object from an existing target.
     *
     * @param target the target to extract the reference from - NOT NULL
     *
     * @throws IllegalArgumentException if target is null
     *
     */
    public TargetRef(final Target target) {
        setTarget(target);
        value = target.getLocURI();
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the value
     *
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * Sets the reference value. If value is null, the empty string is adopted.
     *
     * @param value the reference value - NULL
     */
    public void setValue(String value) {
        this.value = (value == null) ? "" : value;
    }

    /**
     * Gets the Target property
     *
     * @return target the Target property
     */
    public Target getTarget() {
        return this.target;
    }

    /**
     * Sets the Target property
     *
     * @param target the Target property
     */
    public void setTarget(Target target) {
        if (target == null) {
            throw new IllegalArgumentException("target cannot be null");
        }
        this.target = target;
    }
}
