/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core.dm.ddf;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import org.apache.commons.collections.map.ListOrderedMap;

/**
 * Corresponds to the &lt;DMAcc&gt; in the management tree
 *
 *
 *
 * @version $Id: DMAcc.java,v 1.2 2006/08/07 21:09:19 nichele Exp $
 */
public class DMAcc  implements java.io.Serializable {

    // --------------------------------------------------------------- Constants

   // ------------------------------------------------------------ Private data

   private Map dmAccounts;



   // ------------------------------------------------------------ Constructors
   /** For serialization purposes */
   public DMAcc() {}

    /**
     * Creates a new DMAcc object with the given <code>DMAccount</code> and the given name
     *
     * @param dmAccount the dm account
     * @param accountName the name of the dm account
     */
    public DMAcc(final DMAccount dmAccount, final String accountName) {
        this.dmAccounts = new ListOrderedMap();
        this.dmAccounts.put(accountName, dmAccount);
    }


    // ---------------------------------------------------------- Public methods

    /**
     * Add new dm account
     * @param dmAccount the dm account to add
     * @param accountName the name of the dm account to add
     */
    public void addDMAccount(final DMAccount dmAccount, final String accountName) {
        this.dmAccounts.put(accountName, dmAccount);
    }

    /**
     * Gets the dm account with the given name
     *
     * @param accountName the name of the dm account
     * @return the dm account with the given name.<br/><code>null</code> if not exists.
     */
    public DMAccount getDMAccount(final String accountName) {
        return (DMAccount)this.dmAccounts.get(accountName);
    }


    /**
     * Rename, if exists, a <code>DMAccount</code> contained in this <code>DMAcc</code>
     *
     * @param oldAccountName the name of the dm account to rename
     * @param newAccountName the new name of the dm account to rename
     */
    public void renameDMAccount(String oldAccountName, String newAccountName) {

        if (dmAccounts == null) {
            // no accounts
            return ;
        }

        //
        // In order to rename a dmAccount maintaining the order, we must create
        // a new ListOrderedMap
        //
        Set keys = dmAccounts.keySet();
        Iterator itKeys = keys.iterator();
        String accountName = null;
        Map newDmAccounts = new ListOrderedMap();
        while (itKeys.hasNext()) {
            accountName = (String)itKeys.next();
            if (accountName.equalsIgnoreCase(oldAccountName)) {
                newDmAccounts.put(newAccountName, dmAccounts.get(oldAccountName));
            } else {
                newDmAccounts.put(accountName, dmAccounts.get(accountName));
            }
        }
        this.dmAccounts = newDmAccounts;
    }


    /**
     * Gets the dm accounts
     *
     * @return the dm accounts
     */
    public Map getDMAccounts() {
        return dmAccounts;
    }

    /**
     * Sets the dm accounts
     *
     * @param dmAccounts the dmAccount to set
     */
    public void setDMAccounts(Map dmAccounts) {
        this.dmAccounts = dmAccounts;
    }


    /**
     * Returns the number of dm accounts
     *
     * @return the number of dm accounts
     */
    public int numberOfDMAccounts() {
        return dmAccounts.size();
    }


}
