/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.core.dm.ddf;


/**
 * Corresponds to the &lt;DevDetail&gt; element in the SyncML devinf DTD
 *
 *
 *
 * @version $Id: DevDetail.java,v 1.2 2006/08/07 21:09:19 nichele Exp $
 */

public class DevDetail {

    // --------------------------------------------------------------- Constants

   public static final String DEVDETAIL_URI_MAX_DEPTH      = "/URI/MaxDepth";
   public static final String DEVDETAIL_URI_MAX_TOT_LEN    = "/URI/MaxToLen"  ;
   public static final String DEVDETAIL_URI_MAX_SEG_LEN    = "/URI/MaxSegLen"  ;
   public static final String DEVDETAIL_DEV_TYP            = "/DevTyp";
   public static final String DEVDETAIL_OEM                = "/OEM";
   public static final String DEVDETAIL_FWV                = "/FwV";
   public static final String DEVDETAIL_SWV                = "/SwV";
   public static final String DEVDETAIL_HWV                = "/HwV";
   public static final String DEVDETAIL_LRG_OBJ            = "/LrgObj";


   // ------------------------------------------------------------ Private data
   private String uriMaxDepth;
   private String uriMaxLen;
   private String uriMaxSegLen;
   private String devTyp;
   private String oem;
   private String fwVersion;
   private String swVersion;
   private String hwVersion;
   private String lrgObj;


   // ------------------------------------------------------------ Constructors
   /** For serialization purposes */
   protected DevDetail() {}

    /**
     * Creates a new DevDetail object with the given parameters
     *
     * @param uriMaxDepth the maximun depth of the management tree
     * @param uriMaxLen the maximun total length of any uri
     * @param uriMaxSegLen the maximun total length of any uri segment
     * @param devTyp the device type, e.g. PDA, pager, phone
     * @param oem the original equipment manufacturer
     * @param fwVersion the firmware version
     * @param swVersion the software version
     * @param hwVersion the hardware version
     * @param lrgObj indicates whether the device supports large object
     *
     */
    public DevDetail(final String uriMaxDepth,
                     final String uriMaxLen,
                     final String uriMaxSegLen,
                     final String devTyp,
                     final String oem,
                     final String fwVersion,
                     final String swVersion,
                     final String hwVersion,
                     final String lrgObj) {
        this.uriMaxDepth  = uriMaxDepth;
        this.uriMaxLen    = uriMaxLen;
        this.uriMaxSegLen = uriMaxSegLen;
        this.devTyp       = devTyp;
        this.oem          = oem;
        this.fwVersion    = fwVersion;
        this.swVersion    = swVersion;
        this.hwVersion    = hwVersion;
        this.lrgObj       = lrgObj;
    }


    // ---------------------------------------------------------- Public methods


    /**
     * Gets the uriMaxDepth
     *
     * @return  the uriMaxDepth
     */
    public String getUriMaxDepth() {
        return uriMaxDepth;
    }

    /**
     * Sets the uriMaxDepth
     *
     * @param  the uriMaxDepth
     */
    public void setUriMaxDepth(String uriMaxDepth) {
        this.uriMaxDepth = uriMaxDepth;
    }

    /**
     * Gets the uriMaxLen
     *
     * @return  the uriMaxLen
     */
    public String getUriMaxLen() {
        return uriMaxLen;
    }

    /**
     * Sets the uriMaxLen
     *
     * @param  the uriMaxLen
     */
    public void setUriMaxLen(String uriMaxLen) {
        this.uriMaxLen = uriMaxLen;
    }

    /**
     * Gets the uriMaxSegLen
     *
     * @return  the uriMaxSegLen
     */
    public String getUriMaxSegLen() {
        return uriMaxSegLen;
    }

    /**
     * Sets the uriMaxSegLen
     *
     * @param  the uriMaxSegLen
     */
    public void setUriMaxSegLen(String uriMaxSegLen) {
        this.uriMaxSegLen = uriMaxSegLen;
    }

    /**
     * Gets the uriMaxDepth
     *
     * @return  the uriMaxDepth
     */
    public String getDevTyp() {
        return devTyp;
    }

    /**
     * Sets the uriMaxDepth
     *
     * @param  the uriMaxDepth
     */
    public void setDevTyp(String devTyp) {
        this.devTyp = devTyp;
    }

    /**
     * Gets the oem
     *
     * @return  the oem
     */
    public String getOem() {
        return oem;
    }

    /**
     * Sets the oem
     *
     * @param  the oem
     */
    public void setOem(String oem) {
        this.oem = oem;
    }

    /**
     * Gets the fwVersion
     *
     * @return  the fwVersion
     */
    public String getFwVersion() {
        return fwVersion;
    }

    /**
     * Sets the fwVersion
     *
     * @param  the fwVersion
     */
    public void setFwVersion(String fwVersion) {
        this.fwVersion = fwVersion;
    }

    /**
     * Gets the swVersion
     *
     * @return  the swVersion
     */
    public String getSwVersion() {
        return swVersion;
    }

    /**
     * Sets the swVersion
     *
     * @param  the swVersion
     */
    public void setSwVersion(String swVersion) {
        this.swVersion = swVersion;
    }

    /**
     * Gets the hwVersion
     *
     * @return  the hwVersion
     */
    public String getHwVersion() {
        return hwVersion;
    }

    /**
     * Sets the hwVersion
     *
     * @param  the hwVersion
     */
    public void setHwVersion(String hwVersion) {
        this.hwVersion = hwVersion;
    }

    /**
     * Gets the lrgObj
     *
     * @return  the lrgObj
     */
    public String getLrgObj() {
        return lrgObj;
    }

    /**
     * Sets the lrgObj
     *
     * @param  the lrgObj
     */
    public void setLrgObj(String lrgObj) {
        this.lrgObj = lrgObj;
    }

}
