/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */


package com.funambol.framework.core.dm.ddf;

import java.util.*;

/**
 * Corresponds to the &lt;DevInf&gt; element in the SyncML devinf DTD
 *
 *
 *
 * @version $Id: DevInfo.java,v 1.3 2006/08/07 21:09:19 nichele Exp $
 */
public final class DevInfo implements java.io.Serializable {

    // --------------------------------------------------------------- Constants

    public static final String DEVINFO_DEV_ID = "/DevId";
    public static final String DEVINFO_MAN    = "/Man"  ;
    public static final String DEVINFO_MOD    = "/Mod"  ;
    public static final String DEVINFO_DMV    = "/DmV"  ;
    public static final String DEVINFO_LANG   = "/Lang" ;

    // ------------------------------------------------------------ Private data
    private String devId;
    private String man;
    private String mod;
    private String dmV;
    private String lang;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    protected DevInfo() {}

    /**
     * Creates a new DevInfo object with the given parameters
     *
     * @param devId the device identifier
     * @param man the device manufacturer
     * @param mod the device model name
     * @param dmV a SyncML DM client version identifier
     * @param lang the device software version
     */
    public DevInfo(final String devId,
                   final String man  ,
                   final String mod  ,
                   final String dmV  ,
                   final String lang ) {
        this.devId = devId;
        this.man   = man  ;
        this.mod   = mod  ;
        this.dmV   = dmV  ;
        this.lang  = lang ;
    }

    // ---------------------------------------------------------- Public methods
    /**
     * Gets the devId
     *
     * @return  the devId
     */
    public String getDevId() {
        return devId;
    }

    /**
     * Sets the devId
     *
     * @param  the devId
     */
    public void setDevId(String devId) {
        this.devId = devId;
    }

    /**
     * Gets the device manufacturer property
     *
     * @return the device manufacturer property
     */
    public String getMan() {
        return man;
    }

    /**
     * Sets the device manufacturer property
     *
     * @param man the device manufacturer property
     *
     */
    public void setMan(String man) {
        this.man = man;
    }

    /**
     * Gets the model name of device
     *
     * @return the model name of device
     */
    public String getMod() {
        return mod;
    }

    /**
     * Sets the device model property
     *
     * @param mod the device model property
     *
     */
    public void setMod(String mod) {
        this.mod = mod;
    }

    /**
     * Gets the SyncML DM client version
     *
     * @return the SyncML DM client version
     */
    public String getFwV() {
        return dmV;
    }

    /**
     * Sets the SyncML DM client version
     *
     * @param dmV the SyncML DM client version
     *
     */
    public void setDmV(String dmV) {
        this.dmV =dmV;
    }

    /**
     * Gets the device current language setting
     *
     * @return the device current language setting
     */
    public String getLang() {
        return lang;
    }

    /**
     * Sets the device current language setting
     *
     * @param lang the device current language setting
     *
     */
    public void setLang(String lang) {
        this.lang = lang;
    }
}
