/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine.dm;

import java.security.Principal;

import com.funambol.framework.engine.dm.DeviceDMState;
import com.funambol.framework.core.dm.ddf.DevInfo;

/**
 * The ManagementProcessor interface defines the structure of an object able
 * to handle management sessions.
 *
 *
 */
public interface ManagementProcessor {

    /**
     * Called when a management session is started for the given principal.
     * sessionId is the content of the SessionID element of the OTA DM message.
     *
     * @param sessionId the content of the SessionID element of the OTA DM message
     * @param principal the principal who started the management session
     * @param type the management session type (as specified in the message Alert)
     * @param devInfo device info of the device under management
     * @param dmstate device management state
     *
     * @throws ManagementException in case of errors
     */
    void beginSession(String        sessionId,
                      Principal     p        ,
                      int           type     ,
                      DevInfo       devInfo  ,
                      DeviceDMState dmstate  )
    throws ManagementException;

    /**
     * Called when the management session is closed. CompletionCode can be one
     * of:
     * <ul>
     *  <li>DM_SESSION_SUCCESS</li>
     *  <li>DM_SESSION_ABORT</li>
     *  <li>DM_SESSION_FAILED</li>
     *
     * @param completionCode the management session competion code
     *
     * @throws ManagementException in case of errors
     */
    void endSession(int completionCode)
    throws ManagementException;

    /**
     * Called to retrieve the next management operations to be performed.
     *
     * @returns an array of ManagementOperation representing the management
     *          operations to be performed.
     *
     * @throws ManagementException in case of errors
     */
    ManagementOperation[] getNextOperations()
    throws ManagementException;

    /**
     * Called to set the results of a set of management operations.
     *
     * @param results the results of a set of management operations.
     *
     * @throws ManagementException in case of errors
     */
    void setOperationResults(ManagementOperationResult[] results)
    throws ManagementException;

    /**
     * Name to uniquely identify the management processor instance (each
     * installed management processor should have a different name in its
     * configuration file).
     *
     * @return the management processor name
     */
    String getName();
}
