/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.framework.engine.dm;


import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Iterator;

/**
 * Base class for tree manipulation management commands such as Add, Replace,
 * Delete and so on.
 * <p>
 * These operations affect on or mode management nodes that in this simple
 * implementation are represented in a Map {key-value}. The key is the path
 * in the configuration tree.
 *
 *
 *
 * @version $Id: TreeManagementOperation.java,v 1.3 2006/08/07 21:09:20 nichele Exp $
 */
public abstract class TreeManagementOperation
extends ManagementOperation
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private Map nodes;

    // ------------------------------------------------------------ constructors

    protected TreeManagementOperation() {
        nodes = new LinkedHashMap();
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the nodes property
     *
     * @return the nodes property
     */
    public Map getNodes() {
        return nodes;
    }

    /**
     * Set the nodes property
     *
     * @param newNodes the new values
     */
    public void setNodes(Map newNodes) {
        nodes = new LinkedHashMap();
        if (newNodes == null) {
            return;
        }

        nodes.putAll(newNodes);
    }

    /**
     * Add the given node
     *
     * @param node the node to add
     */
    public void addNode(TreeNode node) {
        if (node == null) {
            return;
        }

        if (this.nodes == null) {
            this.nodes = new LinkedHashMap();
        }
        this.nodes.put(node.getName(), node);
    }
}