/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.engine.pipeline;

import java.io.Serializable;
import java.util.HashMap;

/**
 * This class allows at the elements of the pipeline to add their property
 * independently regarding the other elements.
 * <p>
 * Standard properties are:
 * <ul>
 *   funambol.sessionid - the server session id
 * </ul>
 * <p>
 * <b>NOTE:</b> the prefix <i>funambol.</i> for property keys is reserved for
 * Funambol internal use.
 *
 * @version $Id: MessageProcessingContext.java,v 1.2 2006/08/07 21:09:20 nichele Exp $
 */
public class MessageProcessingContext implements Serializable {

    // --------------------------------------------------------------- Constants

    public static final String PROPERTY_SESSIONID = "funambol.sessionid";

    // ------------------------------------------------------------ Private data

    private HashMap properties = new HashMap();

    // ------------------------------------------------------------ Constructors

    // -------------------------------------------------------------- Properties

    /**
     * Getter for properties.
     * @return Value of properties.
     */
    public HashMap getProperties() {
        return this.properties;
    }

    /**
     * Setter for properties.
     * @param properties New value of property.
     */
    public void setProperties(HashMap properties) {
        this.properties = properties;
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Returns the value of the property associated to the given key
     *
     * @param key the context property key
     *
     * @return the property value or null if key was not found
     */
    public Object getProperty(String key) {
        return properties.get(key);
    }

    /**
     * Sets a given context property
     *
     * @param key the context property key
     * @param value the context property value
     *
     */
    public void setProperty(String key, Object value) {
        properties.put(key, value);
    }

}
