/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.framework.tools;

import com.funambol.framework.tools.IdGenerator;

/**
 * This class implements an ID generator, that increments the counter each time
 * the next method is called. When the maximum 16 bit integer si reached, it
 * starts again from 1. The first retuned number is 1.
 * <p>
 * SimpleIdGenerator is thread-safe
 *
 * @version $Id: Int16IdGenerator.java,v 1.2 2006/08/07 21:09:23 nichele Exp $
 */
public final class Int16IdGenerator implements IdGenerator, java.io.Serializable {

    // -------------------------------------------------------------- Properties

    /**
     * The counter
     */
    private int counter;

    public int getCounter() {
        return counter;
    }

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new instance of SimpleIdGenerator
     *
     * @param counter the starting value
     * @param increment the increment
     */
    public Int16IdGenerator() {
        counter = 0;
    }

    /**
     * Reset the generator to 0.
     */
    public void reset() {
        counter = 0;
    }

    /**
     * Returns the next value of the counter (incrementing the counter by the
     * increment)
     *
     * @return the next generated value
     */
    public synchronized String next() {
        if (counter == 0x0000ffff) {
            reset();
        }

        return String.valueOf(++counter);
    }

    /**
     * Returns the last generated id (which is the current id).
     *
     * @return the last generated id
     */
    public synchronized String current() {
        return String.valueOf(counter);
    }
}
