/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.server.notification;

import java.util.logging.Logger;
import java.util.logging.Level;

import com.funambol.framework.logging.FunambolLogger;
import com.funambol.framework.notification.Sender;
import com.funambol.framework.notification.NotificationException;
import com.funambol.framework.tools.DbgTools;


/**
 * This is a simple implementation of the Sender interface that simply logs its
 * activity.
 *
 * @version $Id: SimpleSender.java,v 1.4 2006/08/07 21:09:25 nichele Exp $
 */
public class SimpleSender implements Sender {


    // ---------------------------------------------------------- Public Methods

    /**
     * Sends a message
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumber the phone number of the target device
     * @param message the messagge to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessage(int    messageType,
                            String phoneNumber,
                            byte[] message    ,
                            String info       )
    throws NotificationException {
        Logger log = FunambolLogger.getLogger();

        if (log.isLoggable(Level.INFO)) {
            log.info( "Send message \n\tmessageType: "
                    + messageType
                    + "\n\tphoneNumber: "
                    + phoneNumber
                    + "\n\tmessage length: "
                    + ((message != null) ? String.valueOf(message.length) : "unknown")
                    + "\n\tinfo: "
                    + info
            );
            log.info("Message: " + DbgTools.bytesToHex(message));
        }

    }

    /**
     * Sends messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumbers the phone numbers list of the target device
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int      messageType,
                             String[] phoneNumbers,
                             byte[][] message,
                             String   info) throws NotificationException {
        Logger log = FunambolLogger.getLogger();

        if (log.isLoggable(Level.INFO)) {
            log.info( "Send messages \n\tmessageType: "
                      + messageType
                      + "\n\tnum. devices: "
                      + phoneNumbers.length
                      + "\n\tinfo: "
                      + info
                );
            for (int i=0; i<message.length; i++) {
                log.info("Message " + i + ": " + DbgTools.bytesToHex(message[i]));
            }
        }
    }

    /**
     * Sends more messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param contentType the contentType
     * @param macs the macs list
     * @param authMethods the authentication methods
     * @param phoneNumbers the phone number list
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int messageType,
                             String contentType,
                             String[] digest,
                             int[]    authMethods,
                             String[] phoneNumbers,
                             byte[][] messages,
                             String info) throws NotificationException {

        Logger log = FunambolLogger.getLogger();

        if (log.isLoggable(Level.INFO)) {
            log.info( "Send messages \n\tmessageType: "
                      + messageType
                      + "\n\tcontentType: " + contentType
                      + "\n\tnum. devices: "
                      + phoneNumbers.length
                      + "\n\tinfo: "
                      + info
                );
            for (int i=0; i<messages.length; i++) {
                log.info("Phone number " + i + ": " + phoneNumbers[i]);
                log.info("Message " + i + ": " + DbgTools.bytesToHex(messages[i]));
                log.info("Digest " + i + ": " + digest[i]);
            }
        }
    }



}
