/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */
package com.funambol.server.notification;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.funambol.framework.core.bootstrap.Characteristic;
import com.funambol.framework.core.bootstrap.Parm;
import com.funambol.framework.core.bootstrap.WapProvisioningDoc;
import com.funambol.framework.core.dm.ddf.Auth;
import com.funambol.framework.core.dm.ddf.ConNode;
import com.funambol.framework.core.dm.ddf.Connection;
import com.funambol.framework.core.dm.ddf.DMAcc;
import com.funambol.framework.core.dm.ddf.DMAccount;
import com.funambol.framework.core.dm.ddf.NAP;
import com.funambol.framework.core.dm.ddf.PX;
import com.funambol.framework.core.dm.ddf.SyncMLDM;
import com.funambol.framework.logging.FunambolLogger;
import com.funambol.framework.logging.FunambolLoggerName;
import com.funambol.framework.notification.BootstrapMessageBuilder;
import com.funambol.framework.notification.NotificationException;
import com.funambol.framework.tools.Base64;

import org.jibx.runtime.JiBXException;

/**
 * It's a builder for a bootstrap message for Wap Profile.
 *
 *
 *
 * @version $Id: WAPBootstrapMessageBuilder.java,v 1.3 2006/08/07 21:09:25 nichele Exp $
 */
public class WAPBootstrapMessageBuilder implements BootstrapMessageBuilder {

    // --------------------------------------------------------------- Constants
    private static final String VERSION_WAP_PROVISIONIG_DOC     = "1.0";
    private static final String APPLICATION_ID                  = "w7";
    private static final String AAUTH_LEVEL_SERVER              = "APPSRV";
    private static final String AAUTH_LEVEL_CLIENT              = "CLIENT";

    private static final String PROPERTY_NAME_ADDR              = "ADDR";
    private static final String PROPERTY_NAME_APPLICATION_ID    = "APPID";
    private static final String PROPERTY_NAME_NAME              = "NAME";
    private static final String PROPERTY_NAME_PROVIDER_ID       = "PROVIDER-ID";
    private static final String PROPERTY_NAME_AAUTHSECRET       = "AAUTHSECRET";
    private static final String PROPERTY_NAME_AAUTHDATA         = "AAUTHDATA";
    private static final String PROPERTY_NAME_AAUTHNAME         = "AAUTHNAME";
    private static final String PROPERTY_NAME_AAUTHLEVEL        = "AAUTHLEVEL";
    private static final String PROPERTY_NAME_PORTNBR           = "PORTNBR";
    private static final String PROPERTY_NAME_NAP_ADDRESS       = "NAP-ADDRESS";
    private static final String PROPERTY_NAME_NAP_BEARER        = "BEARER";
    private static final String PROPERTY_NAME_NAP_ADDRTYPE      = "NAP-ADDRTYPE";
    private static final String PROPERTY_NAME_NAP_ID            = "NAPID";
    private static final String PROPERTY_NAME_NAP_NAME          = "NAME";

    private static final String PROPERTY_NAME_AUTHTYPE          = "AUTHTYPE";
    private static final String PROPERTY_NAME_AUTHNAME          = "AUTHNAME";
    private static final String PROPERTY_NAME_AUTHSECRET        = "AUTHSECRET";

    private static final String PROPERTY_NAME_PXADDR            = "PXADDR";
    private static final String PROPERTY_NAME_PXADDRTYPE        = "PXADDRTYPE";

    private static final String PROPERTY_NAME_PXAUTH_TYPE       = "PXAUTH-TYPE";
    private static final String PROPERTY_NAME_PXAUTH_ID         = "PXAUTH-ID";
    private static final String PROPERTY_NAME_PXAUTH_PW         = "PXAUTH-PW";


    // -------------------------------------------------------------- Properties

    // ------------------------------------------------------------ Private data
    private Logger log = null;

    // ------------------------------------------------------------- Constructor
    /**
     * Creates a new WapBootstrapMessageBuilder
     */
    public WAPBootstrapMessageBuilder() {
        log = FunambolLogger.getLogger(FunambolLoggerName.SERVER_DM_BOOTSTRAP);
    }


    // ---------------------------------------------------------- Public Methods

    /**
     * Returns the wbxml representation of the bootstrap message for the given <code>SycnMLDM</code> object.
     *
     * @param serverUri the server URI
     * @param deviceId the device id
     * @param phoneNumber the phone number
     * @param syncMLDM the SyncMLDM object
     *
     * @throws NotificationException if a error occurs during message creation
     * @return byte[] the wbxml representation of the bootstrap messege
     */
    public byte[] buildMessage(String serverUri, String deviceId,
                               String phoneNumber, SyncMLDM syncMLDM) throws NotificationException {

        if (log.isLoggable(Level.INFO)) {
            log.info("Calling buildMessage in WapBootstrapMessageBuilder");
        }

        WapProvisioningDoc wapProvisioningDoc = getWapProvisioningDoc(syncMLDM);

        byte[] message = null;

        try {
            message = WBXMLTools.toWBXML(wapProvisioningDoc);
        } catch (Exception e) {
            throw new NotificationException("Error during the conversion of the bootstrap message in wbxml", e);
        }



        return message;

    }


    // --------------------------------------------------------- Private Methods

    /**
      * Returns the <code>WapProvisioningDoc</code> object corresponds to the bootstrap message
      * for the given <code>SycnMLDM</code> object.
      * @param serverUri the server uri
      * @param deviceId the device id
      * @param syncMLDM the SyncMLDM object
      *
      * @return WapProvisioningDoc the <code>WapProvisioningDoc</code> corresponds to the bootstrap message
      */
    private WapProvisioningDoc getWapProvisioningDoc(SyncMLDM syncMLDM) {

        WapProvisioningDoc wapProvisioningDoc = new WapProvisioningDoc(VERSION_WAP_PROVISIONIG_DOC);

        DMAcc dmAcc = syncMLDM.getDmAcc();

        Map accounts = dmAcc.getDMAccounts();
        Set keys = accounts.keySet();
        Iterator itAccounts = keys.iterator();

        DMAccount dmAccount = null;
        String accountName  = null;
        Characteristic application = null;

        while (itAccounts.hasNext()) {
            accountName = (String)itAccounts.next();
            dmAccount = (DMAccount)accounts.get(accountName);

            // Characteristic list for the dmAccount
            application = getCharacteristic(dmAccount);

            // adds characteristic to the main document
            wapProvisioningDoc.addCharacteristic(application);
        }

        // creates characteristic for Con node
        ArrayList chConnList = getCharacteristics(syncMLDM.getCon());

        wapProvisioningDoc.addCharacteristicList(chConnList);

        if (log.isLoggable(Level.FINEST)) {
            try {
                log.finest("WapBootstrapMessage - xml: " + wapProvisioningDoc.toXml());
            } catch (JiBXException ex) {
                log.finest("Error logging WapBootstrapMessage [" + ex.getMessage() + "]");
            }
        }


        return wapProvisioningDoc;
    }

    /**
     * Returns the first <code>DMAccount</code> contained in the given <code>DMAcc</code>
     * @param dmAcc
     * @return DMAccount
     */
    private DMAccount getDMAccount(DMAcc dmAcc) {
        Map dmAccounts = dmAcc.getDMAccounts();
        Set dmAccountNames = dmAccounts.keySet();
        Iterator it = dmAccountNames.iterator();
        DMAccount dmAccount = null;
        while (it.hasNext()) {
            dmAccount = (DMAccount)dmAcc.getDMAccount( (String)it.next());
        }
        return dmAccount;
    }

    /**
     * Returns the <code>Characteristic</code> for the data contained in the given
     * <code>DMAccount</code>
     * @param dmAccount DMAccount
     * @return Characteristic the characteristic for the given DMAccount
     */
    private Characteristic getCharacteristic(DMAccount dmAccount) {

        // Application
        Characteristic application = new Characteristic(Characteristic.TYPE_APPLICATION);
        Parm applicationId         = new Parm(PROPERTY_NAME_APPLICATION_ID, APPLICATION_ID);
        Parm name                  = new Parm(PROPERTY_NAME_NAME, dmAccount.getName());
        Parm providerId            = new Parm(PROPERTY_NAME_PROVIDER_ID, dmAccount.getServerId());

        application.add(applicationId);
        application.add(name);
        application.add(providerId);

        // Server address and port
        Characteristic appAddr     = new Characteristic(Characteristic.TYPE_APPADDR);
        Parm addr                  = new Parm(PROPERTY_NAME_ADDR, dmAccount.getAddress());
        appAddr.add(addr);

        // Port number
        Characteristic port          = new Characteristic(Characteristic.TYPE_PORT);
        Parm portNbr                 = new Parm(PROPERTY_NAME_PORTNBR, String.valueOf(dmAccount.getPortNumber()));
        port.add(portNbr);
        appAddr.add(port);

        // Server credential
        Characteristic appAuthServer = new Characteristic(Characteristic.TYPE_APPAUTH);
        Parm levelServer             = new Parm(PROPERTY_NAME_AAUTHLEVEL, AAUTH_LEVEL_SERVER);
        Parm serverName              = new Parm(PROPERTY_NAME_AAUTHNAME, dmAccount.getServerId());
        Parm serverPw                = new Parm(PROPERTY_NAME_AAUTHSECRET, dmAccount.getServerPassword());

        String serverNonceB64        = new String(Base64.encode(dmAccount.getServerNonce()));
        Parm serverNonce             = new Parm(PROPERTY_NAME_AAUTHDATA, serverNonceB64);

        appAuthServer.add(levelServer);
        appAuthServer.add(serverName);
        appAuthServer.add(serverPw);
        appAuthServer.add(serverNonce);


        // Client credential
        Characteristic appAuthClient = new Characteristic(Characteristic.TYPE_APPAUTH);
        Parm levelClient             = new Parm(PROPERTY_NAME_AAUTHLEVEL, AAUTH_LEVEL_CLIENT);
        Parm clientName              = new Parm(PROPERTY_NAME_AAUTHNAME, dmAccount.getUserName());
        Parm clientPwd               = new Parm(PROPERTY_NAME_AAUTHSECRET, dmAccount.getClientPassword());

        String clientNonceB64        = new String(Base64.encode(dmAccount.getClientNonce()));
        Parm clientNonce             = new Parm(PROPERTY_NAME_AAUTHDATA, clientNonceB64);

        appAuthClient.add(levelClient);
        appAuthClient.add(clientName);
        appAuthClient.add(clientPwd);
        appAuthClient.add(clientNonce);


        // Adds the previous characteristic to the 'Application' characteristic
        application.add(appAddr);
        application.add(appAuthServer);
        application.add(appAuthClient);

        return application;
    }


    /**
     * Returns a ArrayList with the <code>Characteristic</code> for the given <code>ConNode</code>
     * @param conNode ConNode
     * @return ArrayList the list of the characteristics for the given DMAccount
     */
    private ArrayList getCharacteristics(ConNode conNode) {

        ArrayList listCharacteristics = new ArrayList();

        if (conNode == null) {
            return listCharacteristics;
        }

        Set keys = conNode.getConnections().keySet();
        if (keys.size() == 0) {
            return listCharacteristics;
        }


        Iterator itKeys = keys.iterator();

        Connection connection = null;
        String connectionName = null;
        while (itKeys.hasNext()) {
            connectionName = (String)itKeys.next();
            connection     = conNode.getConnection(connectionName);
            listCharacteristics.addAll(getCharacteristic(connection, connectionName));
        }
        return listCharacteristics;
    }

    /**
     * Returns a ArrayList with the <code>Characteristic</code> for the given <code>Connection</code>
     * @param con Connection
     * @param connectionName String
     * @return ArrayList the list of the characteristics for the given connection
     */
    private ArrayList getCharacteristic(Connection con, String connectionName) {
        ArrayList listCharacteristics = new ArrayList();

        NAP conNap = con.getNap();
        PX conPX = con.getPX();

        Characteristic chNap = getCharacteristic(conNap, connectionName);

        Characteristic chPX  = getCharacteristic(conPX, connectionName);

        if (chNap != null) {
            listCharacteristics.add(chNap);
        }

        if (chPX != null) {
            listCharacteristics.add(chPX);
        }


        return listCharacteristics;
    }

    /**
     * Returns the <code>Characteristic</code> for the given <code>NAP</code>
     * @param conNap NAP
     * @param connectionName String
     * @return Characteristic the characteristics for the given nap
     */
    private Characteristic getCharacteristic(NAP conNap, String connectionName) {

        if (conNap == null) {
            return null;
        }

        Characteristic chNap = new Characteristic(Characteristic.TYPE_NAPDEF);
        Parm napId           = new Parm(PROPERTY_NAME_NAP_ID,       connectionName);
        Parm napName         = new Parm(PROPERTY_NAME_NAP_NAME,     connectionName);
        Parm napBearer       = new Parm(PROPERTY_NAME_NAP_BEARER,   conNap.getBearer());
        Parm napAddress      = new Parm(PROPERTY_NAME_NAP_ADDRESS,  conNap.getAddress());
        Parm napAddressType  = new Parm(PROPERTY_NAME_NAP_ADDRTYPE, conNap.getAddressType());

        chNap.add(napId);
        chNap.add(napBearer);
        chNap.add(napAddress);
        chNap.add(napAddressType);


        Set keysAuths = conNap.getAuths().keySet();
        Iterator itKeys = keysAuths.iterator();
        Auth conAuth = null;
        String authName = null;
        while (itKeys.hasNext()) {
            authName = (String)itKeys.next();
            conAuth = conNap.getAuth(authName);
            chNap.add(getCharacteristic(conAuth, authName, 0));
        }

        return chNap;
    }


    /**
     * Returns the <code>Characteristic</code> for the given <code>PX</code>
     * @param conPX PX
     * @param connectionName String
     * @return Characteristic the characteristics for the given px
     */
    private Characteristic getCharacteristic(PX conPX, String connectionName) {

        if (conPX == null) {
            return null;
        }


        Characteristic chPXLogical  = new Characteristic(Characteristic.TYPE_PXLOGICAL);
        Characteristic chPXPhisical = new Characteristic(Characteristic.TYPE_PXPHYSICAL);


        chPXLogical.add(chPXPhisical);


        Parm pxAddress     = new Parm(PROPERTY_NAME_PXADDR, conPX.getAddress());
        Parm pxAddressType = new Parm(PROPERTY_NAME_PXADDRTYPE, conPX.getAddressType());


        Characteristic chPXPort = new Characteristic(Characteristic.TYPE_PORT);
        Parm pxPortNbr          = new Parm(PROPERTY_NAME_PORTNBR, conPX.getPortNbr());
        chPXPort.add(pxPortNbr);

        chPXPhisical.add(pxAddress);
        chPXPhisical.add(pxAddressType);
        chPXPhisical.add(chPXPort);


        Set keysAuths = conPX.getAuths().keySet();
        Iterator itKeys = keysAuths.iterator();
        Auth conAuth = null;
        String authName = null;
        while (itKeys.hasNext()) {
            authName = (String)itKeys.next();
            conAuth = conPX.getAuth(authName);
            chPXPhisical.add(getCharacteristic(conAuth, authName, 1));
        }

        return chPXLogical;

    }


    /**
     * Returns the <code>Characteristic</code> for the given <code>Auth</code>.
     * <br/>
     * If the characteristicType is:
     * <ui>
     *   <li>0 --> the characteristic is created for NAP node
     *   <li>1 --> the characteristic is created for PX node
     * </ui>
     * @param auth Auth
     * @param name String
     * @param characteristicType int 0 indicates that the auth is relative to the Nap node,
     *                               1 indicates that the auth is relative to the PX node
     * @return Characteristic the characteristic for the given auth
     */
    private Characteristic getCharacteristic(Auth auth, String name, int characteristicType) {

        Characteristic chAuth = null;

        String id = auth.getId();
        String secret = auth.getSecret();

        switch (characteristicType) {
            case 0:

                // NAP
                chAuth = new Characteristic(Characteristic.TYPE_NAPAUTHINFO);

                chAuth.add(new Parm(PROPERTY_NAME_AUTHTYPE, name));
                chAuth.add(new Parm(PROPERTY_NAME_AUTHNAME, id));
                chAuth.add(new Parm(PROPERTY_NAME_AUTHSECRET, secret));

                break;

            case 1:

                // PX
                chAuth = new Characteristic(Characteristic.TYPE_PXAUTHINFO);

                chAuth.add(new Parm(PROPERTY_NAME_PXAUTH_TYPE, name));
                chAuth.add(new Parm(PROPERTY_NAME_PXAUTH_ID, id));
                chAuth.add(new Parm(PROPERTY_NAME_PXAUTH_PW, secret));

                break;

            default:

        }

        return chAuth;
    }

}
