/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the Honest Public License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Honest Public License for more details.
 *
 * You should have received a copy of the Honest Public License
 * along with this program; if not, write to Funambol,
 * 643 Bair Island Road, Suite 305 - Redwood City, CA 94063, USA
 */

package com.funambol.transport.http.server;

import java.util.HashMap;

import javax.servlet.http.*;
import javax.naming.*;
import javax.ejb.CreateException;
import javax.ejb.RemoveException;
import javax.ejb.EJBException;

import com.funambol.framework.transport.http.SyncHolder;
import com.funambol.framework.server.SyncResponse;
import com.funambol.server.syncbean.SyncLocal;
import com.funambol.server.syncbean.SyncHomeLocal;

import com.funambol.framework.core.Sync4jException;
import com.funambol.framework.server.error.ServerException;
import com.funambol.framework.server.error.ServerFailureException;
import com.funambol.framework.server.error.NotImplementedException;
import com.funambol.framework.protocol.ProtocolException;

/**
 * Implementes a <i>SyncHolder</i> wrapping a local EJB.
 *
 *
 * @version $Id: LocalEJBSyncHolder.java,v 1.2 2006/08/07 21:09:26 nichele Exp $
 */
public class LocalEJBSyncHolder implements SyncHolder {

    // --------------------------------------------------------------- Constants

    public static final String SYNCEJB_HOME_JNDI_NAME = "java:comp/env/ejb/LocalSyncBean";

    // ------------------------------------------------------------ Private data

    private SyncLocal     sync              = null;
    private String        sessionId         = null;
    private SyncHomeLocal home              = null;
    private long          creationTimestamp       ;

    // ------------------------------------------------------------ Constructors

    public LocalEJBSyncHolder() throws NamingException {
        InitialContext ctx = new InitialContext();
        home = (SyncHomeLocal)ctx.lookup(SYNCEJB_HOME_JNDI_NAME);
        creationTimestamp = System.currentTimeMillis();
    }

    // ---------------------------------------------------------- Public methods

    /** Processes an incoming message.
     *
     * @param requestData the SyncML request as stream of bytes
     * @param contentType the content type associated with the request
     * @param hmacHeader the hmac value associated with the request
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processMessage(byte[] requestData, String contentType, String hmacHeader)
    throws ServerException {
        return sync.processMessage(requestData, contentType, hmacHeader);
    }

    public void setSessionId(String sessionId) throws Sync4jException {
        try {
            sync = home.create(sessionId);
        } catch (CreateException e) {
            throw new ServerFailureException(e);
        }

        this.sessionId = sessionId;
    }

    public String getSessionId() {
        return sessionId;
    }

    /** Called when the SyncHolder is not required any more. It gives the holder
     * an opportunity to do clean up and releaseing of resources.
     *
     * @throws java.lang.Exception in case of error. The real exception is stored
     * in the cause.
     *
     */
    public void close() throws Exception {
        try {
            sync.remove();
        } catch (RemoveException e) {
            throw new Exception("Error in closing the SyncHolder", e);
        } catch (EJBException e) {
            throw new Exception("Error in closing the SyncHolder", e);
        }
    }

    /**
     * Returns the creation timestamp (in milliseconds since midnight, January
     * 1, 1970 UTC).
     *
     * @see com.funambol.framework.transport.http.SyncHolder
     */
    public long getCreationTimestamp() {
        return creationTimestamp;
    }
}
